package Bundle::Font;

our $VERSION = '0.01';

1;
__END__;


=head1 NAME

Bundle::Font - a bundle to install Font modules and dependencies

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::Font'  

=head1 CONTENTS

Encode::compat

PostScript::File

PostScript::Font

Net::LPR

SVG

SVG::Metadata

Image::ExifTool

Image::ANSI

Text::Unidecode

SDL

YAML

Tk

Tk::JPEG::Lite

Text::PDF

Bundle::Gnome2

Gtk2

Gtk2::CV

Tk::FontDialog

Tk::Workspace

Image::XBin

Image::ANSI

SWF::Builder

Games::OpenGL::Font::2D

PDF::FromHTML

PDF::Template

HTML::TagReader

Prima

AutoLoader

PDF::API2

Module::Build

Test::More

Test::Simple

SDL::App

File::Spec

Getopt::Std

File::stat

Unicode::Normalize

XML::Parser

XML::Parser::Expat

Algorithm::Diff

Data::Dumper

GD

GD::RPPNG

X11::Protocol

Glib

Compress::Zlib

BerkeleyDB

AnyEvent

Locale::Recode

TeX::Encode

Combine::FromTeX

XML::XPathScript

Text::BibTeX

TeX::DVI

Template::Latex

Printer

HTML::Entities

URI::Escape

Class::Accessor::Fast

LaTeX::Parser

Text::Refer

Term::Gnuplot

Hardware::UPS::Perl::General

File::Type

Text::Widont

Text::AutoFormat

Font::BDF::Reader

Font::AFM

Font::TFM

Font::TTFMetrics

Font::Fret

Font::FNT

Font::GlyphNames

SDL::sdlpl

Bundle::Encode

Bundle::Unicode

=head1 SEE ALSO

Font::FreeType had some problems. It will need to be downloaded,
installed, and fixed manually.

=head1 AUTHOR

Kevin W. Henwood, <Khen1950fx@aol.com>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2007 by Kevin W. Henwood

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.8 or,
at your option, any later version of Perl 5 you may have available.


=cut
